#! /usr/bin/env python
##############################################################################
#
# Routine: renameFITS.py
#
# Purpose:  The renameFITS tool does the following:
#  Renames FITS files from the *_long_extension.fits to the *_ext.fits form,
#  i.e. it translates the long (> 3 character ) COS file extensions to the three
#     character file extension that DADS expects.
#
# Syntax: 
#
#  renameFITS.py   <filename>...
#
# Arguments:
#
#   filename     The name of the file(s) to be renamed.
#
#
# Returns: nothing
#
# modification history:
#
#   date    opr     who     reason
# -------- -----  --------  --------------------------------------
# 11/04/02 46838  Binegar   first version
# 07/06/07 57539  Sherbert  Correct the comment above
#
##############################################################################
import sys 
import os
import glob
import operator
import re
import string
import tempfile
import urllib


if len(sys.argv) < 2:
    print "Usage: renameFITS.py  <filename>..."
else:
    filenames = sys.argv[1:]

# regular expression to match filename ending in .FITS or .fits
dotfits_suffix = re.compile(".+\.fits$", re.IGNORECASE)
usfits_suffix = re.compile(".+_fits$", re.IGNORECASE)

COS_tran = {"pha_a"      : "pha",
	    "pha_b"      : "phb",
	    "rawtag_a"   : "rta",
	    "rawtag_b"   : "rtb",
	    "rawtag"     : "rtg",
	    "rawimage_a" : "ria",
	    "rawimage_b" : "rib",
	    "rawimage"   : "rim"}


for filename in filenames:
    if dotfits_suffix.match(filename):
	rootname = filename[:string.rindex(filename, '.')]
       
    else:
	print "Filename does not end in \"fits\": " + filename
	continue
	
    i = string.rindex(rootname, '_')

    exts = COS_tran.keys()
    for ext in exts:
	if re.search(".+" + ext + "$", rootname):
	    rootname = string.replace(rootname, ext, COS_tran[ext])

    new_filename = rootname + '.fits'
    
    os.rename(filename, new_filename)
    print filename + " renamed to: " + new_filename

